@@ -1,7 +1,8 @@
 /*
     MidiLearn.cpp
 
-    Copyright 2016-2020 Will Godfrey
+    Copyright 2016-2020, Will Godfrey
+    Copyright 2021, Will Godfrey, Rainer Hans Liffers
 
     This file is part of yoshimi, which is free software: you can redistribute
     it and/or modify it under the terms of the GNU Library General Public
@@ -32,11 +33,12 @@
 #include <vector>
 #include <string>
 #include <unistd.h>  // for usleep()
-//#include <iostream>
+#include <iostream>
+
+//#include <sys/time.h>
 
 using file::isRegularFile;
 using file::make_legit_filename;
-using file::make_legit_pathname;
 using file::setExtension;
 
 using func::asString;
@@ -203,7 +205,7 @@ bool MidiLearn::writeMidi(CommandBlock *putData, bool in_place)
         do
         {
             ++ tries;
-            ok = synth->interchange.fromMIDI->write(putData->bytes);
+            ok = synth->interchange.fromMIDI.write(putData->bytes);
             if (!ok)
                 usleep(1);
         // we can afford a short delay for buffer to clear
@@ -407,7 +409,6 @@ void MidiLearn::generalOperations(CommandBlock *getData)
     if (control == MIDILEARN::control::clearAll)
     {
         midi_list.clear();
-        synth->setLastfileAdded(TOPLEVEL::XML::MLearn, "");
         updateGui();
         synth->getRuntime().Log("List cleared");
         return;
@@ -770,6 +771,7 @@ void MidiLearn::insertLine(unsigned short int CC, unsigned char chan)
 
 void MidiLearn::writeToGui(CommandBlock *putData)
 {
+#ifdef GUI_FLTK
     if (!synth->getRuntime().showGui)
         return;
     putData->data.part = TOPLEVEL::section::midiLearn;
@@ -777,7 +779,7 @@ void MidiLearn::writeToGui(CommandBlock *putData)
     bool ok = false;
     do
     {
-        ok = synth->interchange.toGUI->write(putData->bytes);
+        ok = synth->interchange.toGUI.write(putData->bytes);
         ++tries;
         if (!ok)
                 usleep(1);
@@ -786,7 +788,8 @@ void MidiLearn::writeToGui(CommandBlock *putData)
     while (!ok && tries < 3);
 
     if (!ok)
-        synth->getRuntime().Log("toGui buffer full!", 2);
+        synth->getRuntime().Log("toGui buffer full!", _SYS_::LogNotSerious | _SYS_::LogError);
+#endif
 }
 
 
@@ -826,6 +829,10 @@ void MidiLearn::updateGui(int opp)
     int lineNo = 0;
     list<LearnBlock>::iterator it;
     it = midi_list.begin();
+/*
+    struct timeval tv1, tv2;
+    gettimeofday(&tv1, NULL);
+*/
     while (it != midi_list.end())
     {
         unsigned short int newCC = (it->CC) & MIDI::CC::maxNRPN;
@@ -847,7 +854,19 @@ void MidiLearn::updateGui(int opp)
         }
         ++it;
         ++lineNo;
+        if (lineNo & 32)
+            usleep(10); // allow message list to clear a bit
     }
+/*
+    gettimeofday(&tv2, NULL);
+    if (tv1.tv_usec > tv2.tv_usec)
+    {
+        tv2.tv_sec--;
+        tv2.tv_usec += 1000000;
+    }
+    int actual = (tv2.tv_sec - tv1.tv_sec) *1000000 + (tv2.tv_usec - tv1.tv_usec);
+    std::cout << "Delay " << to_string(actual) << "uS" << std::endl;
+*/
     if (synth->getRuntime().showLearnedCC == true && !midi_list.empty()) // open the gui editing window
     {
         putData.data.control = MIDILEARN::control::sendRefreshRequest;
@@ -871,8 +890,7 @@ bool MidiLearn::saveList(const string& name)
     }
 
     string file = setExtension(name, EXTEN::mlearn);
-    make_legit_pathname(file);
-
+//    make_legit_filename(file);
     synth->getRuntime().xmlType = TOPLEVEL::XML::MLearn;
     XMLwrapper *xml = new XMLwrapper(synth, true);
     if (!xml)
@@ -951,7 +969,6 @@ bool MidiLearn::loadList(const string& name)
         return false;
     }
     string file = setExtension(name, EXTEN::mlearn);
-    make_legit_pathname(file);
     if (!isRegularFile(file))
     {
         synth->getRuntime().Log("Can't find " + file);
